-- Sorting out Saved Variables and populating our table
---------------------------------------------------------------------------------------------------
local baleFrame = CreateFrame("Frame", "BalefulFrame", UIParent)
baleFrame:RegisterEvent("PLAYER_ENTERING_WORLD")
baleFrame:RegisterEvent("PLAYER_EQUIPMENT_CHANGED")

local function baleInit()
	local charName = UnitName("player")
	local _,charClass = UnitClass("player")
	local classColor = RAID_CLASS_COLORS[charClass].colorStr
	if not BalefulILVLSV or type(BalefulILVLSV) ~= 'table' then BalefulILVLSV = {} end
	if BalefulILVLSV == nil then 
		BalefulILVLSV = {}
	end
	
	BalefulILVLSV[charName] = {} 
	BalefulILVLSV[charName].name = charName 
	BalefulILVLSV[charName].class = charClass 
	BalefulILVLSV[charName].items = {}
	
	for i = 0, 19 do
		local balefulLink = GetInventoryItemLink("player", i)
		if balefulLink then
			local itemName, itemLink,_, itemLevel,_,_,_,_, itemEquipLoc = GetItemInfo(balefulLink)
			table.insert(BalefulILVLSV[charName].items, i, itemLink) 
		end      
	end
end

baleFrame:SetScript("OnEvent", baleInit)

-- Table of all the Baleful Armor
---------------------------------------------------------------------------------------------------
balefulArmor = {
	INVTYPE_HEAD = {
		"Baleful Plate Hood",
		"Baleful Cloth Hood",
		"Baleful Mail Hood",
		"Baleful Leather Hood",
	},
	INVTYPE_NECK = { "Baleful Pendant" },
	INVTYPE_SHOULDER = {
		"Baleful Cloth Spaulders",
		"Baleful Leather Spaulders",
		"Baleful Mail Spaulders",
		"Baleful Plate Spaulders",
	},
	INVTYPE_CHEST = {
		"Baleful Plate Robe",
		"Baleful Cloth Robe",
		"Baleful Leather Tunic",
		"Baleful Mail Robe",
	},
	INVTYPE_WAIST = {
		"Baleful Cloth Girdle",
		"Baleful Mail Girdle",
		"Baleful Plate Girdle",
		"Baleful Mail Girdle",
	},
	INVTYPE_LEGS = {
		"Baleful Cloth Leggings",
		"Baleful Mail Leggings",
		"Baleful Leather Leggings",
		"Baleful Plate Leggings",
	},
	INVTYPE_FEET = {
		"Baleful Cloth Treads",
		"Baleful Mail Treads",
		"Baleful Plate Treads",
		"Baleful Leather Treads",
	},
	INVTYPE_WRIST = {
		"Baleful Cloth Bracers",
		"Baleful Leather Bracers",
		"Baleful Mail Bracers",
		"Baleful Plate Bracers",
	},
	INVTYPE_HAND = {
		"Baleful Cloth Gauntlets",
		"Baleful Mail Gauntlets",
		"Baleful Plate Gauntlets",
		"Baleful Leather Gauntlets",
	},
	INVTYPE_FINGER = { "Baleful Ring" },
	INVTYPE_CLOAK = { "Baleful Cloak" },
}

-- Check if an item is Baleful and if so, add your alts to the tooltip
---------------------------------------------------------------------------------------------------
function AddToTooltip(tooltip)
	local name, link = tooltip:GetItem()
	local itemName = GetItemInfo(link) 
   
	tooltip:AddLine("")
	-- READY FOR THE JANK: I'm sure there's a better way to do this, but I'm too tired to see it
	for i,v in pairs(balefulArmor) do
		if tContains(balefulArmor[i], itemName) then
			for q, w in pairs(BalefulILVLSV) do
				for a, s in pairs(BalefulILVLSV[q].items) do
					local _,itemLink,_,itemLevel,_,_,_,_,itemEquipLoc = GetItemInfo(s) 
					if itemEquipLoc == i then
						tooltip:AddLine(q..": "..itemLink.." ("..itemLevel..")")
					end
				end
			end
		end
	end
end

GameTooltip:HookScript("OnTooltipSetItem", AddToTooltip);
ShoppingTooltip1:HookScript("OnTooltipSetItem", AddToTooltip);
ShoppingTooltip2:HookScript("OnTooltipSetItem", AddToTooltip);



